@@ -1,4 +1,5 @@
 /*
+** Copyright (C) 2014-2015 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2010-2013 Sourcefire, Inc.
 ** Author: Michael R. Altizer <maltizer@sourcefire.com>
 **
@@ -232,7 +233,7 @@ static int iface_get_arptype(AFPacketInstance *instance)
     return ifr.ifr_hwaddr.sa_family;
 }
 
-static AFPacketInstance *create_instance(AFPacket_Context_t *afpc, const char *device)
+static AFPacketInstance *create_instance(const char *device, char *errbuf, size_t errlen)
 {
     AFPacketInstance *instance = NULL;
     struct ifreq ifr;
@@ -240,14 +241,14 @@ static AFPacketInstance *create_instance(AFPacket_Context_t *afpc, const char *d
     instance = calloc(1, sizeof(AFPacketInstance));
     if (!instance)
     {
-        DPE(afpc->errbuf, "%s: Could not allocate a new instance structure.", __FUNCTION__);
+        snprintf(errbuf, errlen, "%s: Could not allocate a new instance structure.", __FUNCTION__);
         goto err;
     }
     instance->buffer = MAP_FAILED;
 
     if ((instance->name = strdup(device)) == NULL)
     {
-        DPE(afpc->errbuf, "%s: Could not allocate a copy of the device name.", __FUNCTION__);
+        snprintf(errbuf, errlen, "%s: Could not allocate a copy of the device name.", __FUNCTION__);
         goto err;;
     }
 
@@ -255,16 +256,16 @@ static AFPacketInstance *create_instance(AFPacket_Context_t *afpc, const char *d
     instance->fd = socket(PF_PACKET, SOCK_RAW, htons(ETH_P_ALL));
     if (instance->fd == -1)
     {
-        DPE(afpc->errbuf, "%s: Could not open the PF_PACKET socket: %s", __FUNCTION__, strerror(errno));
+        snprintf(errbuf, errlen, "%s: Could not open the PF_PACKET socket: %s", __FUNCTION__, strerror(errno));
         goto err;
     }
 
     /* Find the device index of the specified interface. */
     memset(&ifr, 0, sizeof(ifr));
     strncpy(ifr.ifr_name, device, sizeof(ifr.ifr_name));
-        if (ioctl(instance->fd, SIOCGIFINDEX, &ifr) == -1)
+    if (ioctl(instance->fd, SIOCGIFINDEX, &ifr) == -1)
     {
-        DPE(afpc->errbuf, "%s: Could not find index for device %s", __FUNCTION__, instance->name);
+        snprintf(errbuf, errlen, "%s: Could not find index for device %s", __FUNCTION__, instance->name);
         goto err;
     }
     instance->index = ifr.ifr_ifindex;
@@ -609,7 +610,7 @@ static int afpacket_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr,
                 goto err;
             }
             snprintf(intf, len + 1, "%s", dev);
-            instance = create_instance(afpc, intf);
+            instance = create_instance(intf, errbuf, errlen);
             if (!instance)
                 goto err;
 
@@ -741,7 +742,8 @@ static const DAQ_Verdict verdict_translation_table[MAX_DAQ_VERDICT] = {
     DAQ_VERDICT_PASS,       /* DAQ_VERDICT_REPLACE */
     DAQ_VERDICT_PASS,       /* DAQ_VERDICT_WHITELIST */
     DAQ_VERDICT_BLOCK,      /* DAQ_VERDICT_BLACKLIST */
-    DAQ_VERDICT_PASS        /* DAQ_VERDICT_IGNORE */
+    DAQ_VERDICT_PASS,       /* DAQ_VERDICT_IGNORE */
+    DAQ_VERDICT_BLOCK       /* DAQ_VERDICT_RETRY */
 };
 
 static int afpacket_daq_acquire(void *handle, int cnt, DAQ_Analysis_Func_t callback, DAQ_Meta_Func_t metaback, void *user)
@@ -1038,14 +1040,14 @@ static void afpacket_daq_set_errbuf(void *handle, const char *string)
     DPE(afpc->errbuf, "%s", string);
 }
 
-static int afpacket_daq_get_device_index(void *handle, const char *string)
+static int afpacket_daq_get_device_index(void *handle, const char *device)
 {
     AFPacket_Context_t *afpc = (AFPacket_Context_t *) handle;
     AFPacketInstance *instance;
 
     for (instance = afpc->instances; instance; instance = instance->next)
     {
-        if (!strcmp(string, instance->name))
+        if (!strcmp(device, instance->name))
             return instance->index;
     }
 
