@@ -1,5 +1,6 @@
 /****************************************************************************
  *
+ * Copyright (C) 2014-2015 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,7 +30,7 @@
 #include "daq.h"
 #include "daq_api.h"
 
-#define DAQ_MOD_VERSION 2
+#define DAQ_MOD_VERSION 3
 
 #define DAQ_NAME "dump"
 #define DAQ_TYPE (DAQ_TYPE_FILE_CAPABLE | DAQ_TYPE_INTF_CAPABLE | \
@@ -208,7 +209,7 @@ static int dump_daq_start (void* handle)
     const char* name = impl->name ? impl->name : DAQ_DUMP_FILE;
     pcap_t* pcap;
     int dlt;
-    uint16_t snap;
+    int snap;
 
     int ret = impl->module->start(impl->handle);
 
@@ -361,5 +362,6 @@ DAQ_Module_t dump_daq_module_data =
     .hup_prep = NULL,
     .hup_apply = NULL,
     .hup_post = NULL,
+    .dp_add_dc = NULL,
 };
 
