@@ -1,4 +1,5 @@
 /*
+ ** Portions Copyright (C) 2014-2015 Cisco and/or its affiliates. All rights reserved.
  ** Portions Copyright (C) 1998-2013 Sourcefire, Inc.
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -415,8 +416,8 @@ static inline int SetPktHdr (
 
 //-------------------------------------------------------------------------
 
-// forward all but blocks and blacklists:
-static const int s_fwd[MAX_DAQ_VERDICT] = { 1, 0, 1, 1, 0, 1 };
+// forward all but blocks, retries and blacklists:
+static const int s_fwd[MAX_DAQ_VERDICT] = { 1, 0, 1, 1, 0, 1, 0 };
 
 static int daq_nfq_callback(
     struct nfq_q_handle* qh,
